@@ -204,9 +204,6 @@ sub main_loop_iteration {
 sub write_log {
     my ($self, $session, $command, $response) = @_;
 
-    use Data::Printer;
-    p $session;
-
     return unless exists($self->{'epp'}->{'log_dir'});
 
     my $dir = File::Spec->catdir(
@@ -747,7 +744,7 @@ Net::EPP::Server - A simple EPP server implementation.
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
